==> libei-docs-1.3.0-1-armv7h.pkg.tar.xz: usr/share/doc/libei-docs/api/group__libei.js <==
var group__libei =
[
    [ "The logging API", "group__libei-log.html", "group__libei-log" ],
    [ "API for receiver clients", "group__libei-receiver.html", "group__libei-receiver" ],
    [ "API for sender clients", "group__libei-sender.html", "group__libei-sender" ],
    [ "The seat API", "group__libei-seat.html", "group__libei-seat" ],
    [ "The device API", "group__libei-device.html", "group__libei-device" ],
    [ "The region API", "group__libei-region.html", "group__libei-region" ],
    [ "The keymap API", "group__libei-keymap.html", "group__libei-keymap" ],
    [ "ei", "structei.html", null ],
    [ "ei_device", "structei__device.html", null ],
    [ "ei_seat", "structei__seat.html", null ],
    [ "ei_event", "structei__event.html", null ],
    [ "ei_keymap", "structei__keymap.html", null ],
    [ "ei_region", "structei__region.html", null ],
    [ "ei_clock_now_func", "group__libei.html#ga99e8d65477b982a489d63a6cbb1fc913", null ],
    [ "ei_device_capability", "group__libei.html#gab1318147205ede39f209a0fea10168d2", [
      [ "EI_DEVICE_CAP_POINTER", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a224d21cbcea3912a9397db7ccd2ef531", null ],
      [ "EI_DEVICE_CAP_POINTER_ABSOLUTE", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a3a19a902496c179e6f8aa8945f8c5824", null ],
      [ "EI_DEVICE_CAP_KEYBOARD", "group__libei.html#ggab1318147205ede39f209a0fea10168d2acfb4c70916ddefbd7a014726c68f99df", null ],
      [ "EI_DEVICE_CAP_TOUCH", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a6e5aee6c151b8a16b79f09baa84b56fe", null ],
      [ "EI_DEVICE_CAP_SCROLL", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a3912ba86c0ebe332355c8a9bb3542d96", null ],
      [ "EI_DEVICE_CAP_BUTTON", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a959be86bcc33fa64ae19f4486b6fcc54", null ]
    ] ],
    [ "ei_device_type", "group__libei.html#ga7538e9c9574143471ba2f44ee5ba8f2c", [
      [ "EI_DEVICE_TYPE_VIRTUAL", "group__libei.html#gga7538e9c9574143471ba2f44ee5ba8f2cae22e5419221c557f629e3c00e4a5ef67", null ],
      [ "EI_DEVICE_TYPE_PHYSICAL", "group__libei.html#gga7538e9c9574143471ba2f44ee5ba8f2ca540ce17fbb66ab520240927f6cecb33e", null ]
    ] ],
    [ "ei_event_type", "group__libei.html#gad07c425e3144e8751f7a2ea72f6c8a24", [
      [ "EI_EVENT_CONNECT", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24abd53f1a5850d1214fa5f8c7a93a90b1b", null ],
      [ "EI_EVENT_DISCONNECT", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24af58d47d053911ebadda793338cbb1068", null ],
      [ "EI_EVENT_SEAT_ADDED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a33c5b1d1e161e61a2bfd74b572ed46ae", null ],
      [ "EI_EVENT_SEAT_REMOVED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a05269957f1f1019e8029df6a830a00f8", null ],
      [ "EI_EVENT_DEVICE_ADDED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a9c8242c7a492fc3cd6da8fa51c99893f", null ],
      [ "EI_EVENT_DEVICE_REMOVED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a8091756af308414c7662675323f90df6", null ],
      [ "EI_EVENT_DEVICE_PAUSED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24ab66c6ba9d0c198e9c0f9c0b195fc7da4", null ],
      [ "EI_EVENT_DEVICE_RESUMED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a84cc8d1a6f8a62453a4432fd460704f1", null ],
      [ "EI_EVENT_KEYBOARD_MODIFIERS", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24aff64ba089583a48e5b830a4d11226c26", null ],
      [ "EI_EVENT_FRAME", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a4fdb1c66054b4d1df20ccf44dcc9bf7a", null ],
      [ "EI_EVENT_DEVICE_START_EMULATING", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a1400e13c15f347123e047b5b83e252b1", null ],
      [ "EI_EVENT_DEVICE_STOP_EMULATING", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24adbba4d103a53468e44197442c598f0d5", null ],
      [ "EI_EVENT_POINTER_MOTION", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a0fb3e3338359b7df75f7503e26b5231a", null ],
      [ "EI_EVENT_POINTER_MOTION_ABSOLUTE", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a07a999248d90f74fa292f46e185da71a", null ],
      [ "EI_EVENT_BUTTON_BUTTON", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a989e4230fcd1d5c7e94dee6bf1a6f654", null ],
      [ "EI_EVENT_SCROLL_DELTA", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a1299fb46f6a97c31ecc0bd12dc3628e8", null ],
      [ "EI_EVENT_SCROLL_STOP", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a212eda532b2f1beb2e2564de590f560c", null ],
      [ "EI_EVENT_SCROLL_CANCEL", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24afc84799b62b9e5f69b19569293fd91b5", null ],
      [ "EI_EVENT_SCROLL_DISCRETE", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a200596d8564827b436d1c6e02d4e66cb", null ],
      [ "EI_EVENT_KEYBOARD_KEY", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24ae575170be692369915fc8124b6452a56", null ],
      [ "EI_EVENT_TOUCH_DOWN", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24aaf620de50c5c91f7792acb633ccc006a", null ],
      [ "EI_EVENT_TOUCH_UP", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24ae4ac5da4f95e34b06e916522e1bc9ac0", null ],
      [ "EI_EVENT_TOUCH_MOTION", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24ae8d59e55ef1ff7a0f12ca8def4219169", null ]
    ] ],
    [ "ei_keymap_type", "group__libei.html#ga96e7795c6abd16d079358335246b2b5f", [
      [ "EI_KEYMAP_TYPE_XKB", "group__libei.html#gga96e7795c6abd16d079358335246b2b5fa94c8e17187710a0aacb1bdba4128c6dd", null ]
    ] ],
    [ "ei_clock_set_now_func", "group__libei.html#ga25d75b071486bc5b75e8471a440a667f", null ],
    [ "ei_configure_name", "group__libei.html#gaf17df01ec9dce25fb8b4ed39080968b3", null ],
    [ "ei_dispatch", "group__libei.html#ga3e170144a9674137f7e4c5f937eb8236", null ],
    [ "ei_event_get_device", "group__libei.html#ga8c2a79f75599ce241070ad75661fc90d", null ],
    [ "ei_event_get_seat", "group__libei.html#ga6a8671cfdc816d5b38ec6179983ce63e", null ],
    [ "ei_event_get_time", "group__libei.html#gaaa4884879bbfa5edc18d9aa1145f9112", null ],
    [ "ei_event_get_type", "group__libei.html#gac619311f5193b7d1a36e1f22e24591eb", null ],
    [ "ei_event_type_to_string", "group__libei.html#gaf264e15650826eb64b4f94f0a0163c61", null ],
    [ "ei_event_unref", "group__libei.html#gabe9e214da0682d905cade022f5392dd7", null ],
    [ "ei_get_event", "group__libei.html#gabd8f65c96880d85189e66c2156253352", null ],
    [ "ei_get_fd", "group__libei.html#ga5201d70cf99c0dcd5d871d4f9fa45642", null ],
    [ "ei_get_user_data", "group__libei.html#gafbe46db13789086aa9d395d5b244e888", null ],
    [ "ei_is_sender", "group__libei.html#ga134d9bd0dc705ca33e8195248f852fa6", null ],
    [ "ei_new", "group__libei.html#gafbb7811bad7a6dd2bcbc7ad21fb80c6e", null ],
    [ "ei_new_receiver", "group__libei.html#ga2c78c7c8eaab564c4c897ae3462a31e4", null ],
    [ "ei_new_sender", "group__libei.html#ga8823d6faddfea1eb09827c93c4719ebf", null ],
    [ "ei_now", "group__libei.html#ga8b7f0cc2fe35856e71848f2aac526aec", null ],
    [ "ei_peek_event", "group__libei.html#ga8edc0b4a8183230dd81e48859d721e53", null ],
    [ "ei_ref", "group__libei.html#gaf842df56bf30a48410c5718c97373310", null ],
    [ "ei_set_user_data", "group__libei.html#ga5f78f3a7f052822f2f939cf8caa5e503", null ],
    [ "ei_setup_backend_fd", "group__libei.html#ga94d64ac9cf80bedde68fc3336308a539", null ],
    [ "ei_setup_backend_socket", "group__libei.html#ga089db7c248b7ae4a5ef68eed3b1871bc", null ],
    [ "ei_unref", "group__libei.html#ga7d1d76a8c2a78f0df7a805b2c925fde7", null ]
];

==> libei-docs-1.4.1-1-armv7h.pkg.tar.xz: usr/share/doc/libei-docs/api/group__libei.js <==
var group__libei =
[
    [ "The logging API", "group__libei-log.html", "group__libei-log" ],
    [ "API for receiver clients", "group__libei-receiver.html", "group__libei-receiver" ],
    [ "API for sender clients", "group__libei-sender.html", "group__libei-sender" ],
    [ "The seat API", "group__libei-seat.html", "group__libei-seat" ],
    [ "The device API", "group__libei-device.html", "group__libei-device" ],
    [ "The region API", "group__libei-region.html", "group__libei-region" ],
    [ "The keymap API", "group__libei-keymap.html", "group__libei-keymap" ],
    [ "ei", "structei.html", null ],
    [ "ei_device", "structei__device.html", null ],
    [ "ei_seat", "structei__seat.html", null ],
    [ "ei_event", "structei__event.html", null ],
    [ "ei_keymap", "structei__keymap.html", null ],
    [ "ei_region", "structei__region.html", null ],
    [ "ei_touch", "structei__touch.html", null ],
    [ "ei_ping", "structei__ping.html", null ],
    [ "ei_clock_now_func", "group__libei.html#ga99e8d65477b982a489d63a6cbb1fc913", null ],
    [ "ei_device_capability", "group__libei.html#gab1318147205ede39f209a0fea10168d2", [
      [ "EI_DEVICE_CAP_POINTER", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a224d21cbcea3912a9397db7ccd2ef531", null ],
      [ "EI_DEVICE_CAP_POINTER_ABSOLUTE", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a3a19a902496c179e6f8aa8945f8c5824", null ],
      [ "EI_DEVICE_CAP_KEYBOARD", "group__libei.html#ggab1318147205ede39f209a0fea10168d2acfb4c70916ddefbd7a014726c68f99df", null ],
      [ "EI_DEVICE_CAP_TOUCH", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a6e5aee6c151b8a16b79f09baa84b56fe", null ],
      [ "EI_DEVICE_CAP_SCROLL", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a3912ba86c0ebe332355c8a9bb3542d96", null ],
      [ "EI_DEVICE_CAP_BUTTON", "group__libei.html#ggab1318147205ede39f209a0fea10168d2a959be86bcc33fa64ae19f4486b6fcc54", null ]
    ] ],
    [ "ei_device_type", "group__libei.html#ga7538e9c9574143471ba2f44ee5ba8f2c", [
      [ "EI_DEVICE_TYPE_VIRTUAL", "group__libei.html#gga7538e9c9574143471ba2f44ee5ba8f2cae22e5419221c557f629e3c00e4a5ef67", null ],
      [ "EI_DEVICE_TYPE_PHYSICAL", "group__libei.html#gga7538e9c9574143471ba2f44ee5ba8f2ca540ce17fbb66ab520240927f6cecb33e", null ]
    ] ],
    [ "ei_event_type", "group__libei.html#gad07c425e3144e8751f7a2ea72f6c8a24", [
      [ "EI_EVENT_CONNECT", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24abd53f1a5850d1214fa5f8c7a93a90b1b", null ],
      [ "EI_EVENT_DISCONNECT", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24af58d47d053911ebadda793338cbb1068", null ],
      [ "EI_EVENT_SEAT_ADDED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a33c5b1d1e161e61a2bfd74b572ed46ae", null ],
      [ "EI_EVENT_SEAT_REMOVED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a05269957f1f1019e8029df6a830a00f8", null ],
      [ "EI_EVENT_DEVICE_ADDED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a9c8242c7a492fc3cd6da8fa51c99893f", null ],
      [ "EI_EVENT_DEVICE_REMOVED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a8091756af308414c7662675323f90df6", null ],
      [ "EI_EVENT_DEVICE_PAUSED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24ab66c6ba9d0c198e9c0f9c0b195fc7da4", null ],
      [ "EI_EVENT_DEVICE_RESUMED", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a84cc8d1a6f8a62453a4432fd460704f1", null ],
      [ "EI_EVENT_KEYBOARD_MODIFIERS", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24aff64ba089583a48e5b830a4d11226c26", null ],
      [ "EI_EVENT_PONG", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24acca273b1685c98572253ff4b9743a436", null ],
      [ "EI_EVENT_SYNC", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a90aeaa1d5a95d0070b1016e80927a325", null ],
      [ "EI_EVENT_FRAME", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a4fdb1c66054b4d1df20ccf44dcc9bf7a", null ],
      [ "EI_EVENT_DEVICE_START_EMULATING", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a1400e13c15f347123e047b5b83e252b1", null ],
      [ "EI_EVENT_DEVICE_STOP_EMULATING", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24adbba4d103a53468e44197442c598f0d5", null ],
      [ "EI_EVENT_POINTER_MOTION", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a0fb3e3338359b7df75f7503e26b5231a", null ],
      [ "EI_EVENT_POINTER_MOTION_ABSOLUTE", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a07a999248d90f74fa292f46e185da71a", null ],
      [ "EI_EVENT_BUTTON_BUTTON", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a989e4230fcd1d5c7e94dee6bf1a6f654", null ],
      [ "EI_EVENT_SCROLL_DELTA", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a1299fb46f6a97c31ecc0bd12dc3628e8", null ],
      [ "EI_EVENT_SCROLL_STOP", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a212eda532b2f1beb2e2564de590f560c", null ],
      [ "EI_EVENT_SCROLL_CANCEL", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24afc84799b62b9e5f69b19569293fd91b5", null ],
      [ "EI_EVENT_SCROLL_DISCRETE", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24a200596d8564827b436d1c6e02d4e66cb", null ],
      [ "EI_EVENT_KEYBOARD_KEY", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24ae575170be692369915fc8124b6452a56", null ],
      [ "EI_EVENT_TOUCH_DOWN", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24aaf620de50c5c91f7792acb633ccc006a", null ],
      [ "EI_EVENT_TOUCH_UP", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24ae4ac5da4f95e34b06e916522e1bc9ac0", null ],
      [ "EI_EVENT_TOUCH_MOTION", "group__libei.html#ggad07c425e3144e8751f7a2ea72f6c8a24ae8d59e55ef1ff7a0f12ca8def4219169", null ]
    ] ],
    [ "ei_keymap_type", "group__libei.html#ga96e7795c6abd16d079358335246b2b5f", [
      [ "EI_KEYMAP_TYPE_XKB", "group__libei.html#gga96e7795c6abd16d079358335246b2b5fa94c8e17187710a0aacb1bdba4128c6dd", null ]
    ] ],
    [ "ei_clock_set_now_func", "group__libei.html#ga25d75b071486bc5b75e8471a440a667f", null ],
    [ "ei_configure_name", "group__libei.html#gaf17df01ec9dce25fb8b4ed39080968b3", null ],
    [ "ei_disconnect", "group__libei.html#ga472bc523f38eb9996af78f55fd9826b5", null ],
    [ "ei_dispatch", "group__libei.html#ga3e170144a9674137f7e4c5f937eb8236", null ],
    [ "ei_event_get_device", "group__libei.html#ga8c2a79f75599ce241070ad75661fc90d", null ],
    [ "ei_event_get_seat", "group__libei.html#ga6a8671cfdc816d5b38ec6179983ce63e", null ],
    [ "ei_event_get_time", "group__libei.html#gaaa4884879bbfa5edc18d9aa1145f9112", null ],
    [ "ei_event_get_type", "group__libei.html#gac619311f5193b7d1a36e1f22e24591eb", null ],
    [ "ei_event_pong_get_ping", "group__libei.html#ga6c084f068c037e50e40c4005979ed8b8", null ],
    [ "ei_event_type_to_string", "group__libei.html#gaf264e15650826eb64b4f94f0a0163c61", null ],
    [ "ei_event_unref", "group__libei.html#gabe9e214da0682d905cade022f5392dd7", null ],
    [ "ei_get_event", "group__libei.html#gabd8f65c96880d85189e66c2156253352", null ],
    [ "ei_get_fd", "group__libei.html#ga5201d70cf99c0dcd5d871d4f9fa45642", null ],
    [ "ei_get_user_data", "group__libei.html#gafbe46db13789086aa9d395d5b244e888", null ],
    [ "ei_is_sender", "group__libei.html#ga134d9bd0dc705ca33e8195248f852fa6", null ],
    [ "ei_new", "group__libei.html#gafbb7811bad7a6dd2bcbc7ad21fb80c6e", null ],
    [ "ei_new_ping", "group__libei.html#ga7ac7d5e4e88ca0244ac21325939ed43e", null ],
    [ "ei_new_receiver", "group__libei.html#ga2c78c7c8eaab564c4c897ae3462a31e4", null ],
    [ "ei_new_sender", "group__libei.html#ga8823d6faddfea1eb09827c93c4719ebf", null ],
    [ "ei_now", "group__libei.html#ga8b7f0cc2fe35856e71848f2aac526aec", null ],
    [ "ei_peek_event", "group__libei.html#ga8edc0b4a8183230dd81e48859d721e53", null ],
    [ "ei_ping", "group__libei.html#gab87e6789a2a9efa6684c745d48e5467f", null ],
    [ "ei_ping_get_id", "group__libei.html#ga61624bd4cbb20e00433e7a4ad9270bc7", null ],
    [ "ei_ping_get_user_data", "group__libei.html#gaa3617411c0c80f7eb8aaef87ce7c101e", null ],
    [ "ei_ping_ref", "group__libei.html#ga136f323a156fe302d20a440dee40cc22", null ],
    [ "ei_ping_set_user_data", "group__libei.html#gadee548f175905611713fd2ecfbada1d2", null ],
    [ "ei_ping_unref", "group__libei.html#gaef6dd5e3d53e87298095e84ea0e6e7be", null ],
    [ "ei_ref", "group__libei.html#gaf842df56bf30a48410c5718c97373310", null ],
    [ "ei_set_user_data", "group__libei.html#ga5f78f3a7f052822f2f939cf8caa5e503", null ],
    [ "ei_setup_backend_fd", "group__libei.html#ga94d64ac9cf80bedde68fc3336308a539", null ],
    [ "ei_setup_backend_socket", "group__libei.html#ga089db7c248b7ae4a5ef68eed3b1871bc", null ],
    [ "ei_unref", "group__libei.html#ga7d1d76a8c2a78f0df7a805b2c925fde7", null ]
];
